@@ -23,3 +23,12 @@ def generate_hash_id(data):
         ).hexdigest()
     )
     return str(hash_id)
+
+
+def get_subpackage_paths():
+    import stratus_api
+    import pkgutil
+    import os
+    for finder, modname, ispkg in pkgutil.iter_modules(stratus_api.__path__):
+        subpackage_path = os.path.join(finder.path, modname)
+        yield subpackage_path
