@@ -3,6 +3,7 @@ def create_server(spec_dir, custom_home=None,
     import connexion
     import os
     import yaml
+    from stratus_api.core.common import get_subpackage_paths
 
     app = connexion.FlaskApp(
         __name__, port=port,
@@ -19,12 +20,11 @@ def create_server(spec_dir, custom_home=None,
     for spec in os.listdir(spec_dir):
         app.add_api(specification=spec, validate_responses=debug)
 
-    framework_dir = os.path.abspath(__file__).replace('/core/server.py', '/')
-
-    for root, folders, files in os.walk(framework_dir):
-        if 'schemas' in root and 'template' not in root:
-            for spec_file in [i for i in files if 'yaml' in i]:
-                with open(os.path.join(root, spec_file), 'rt') as f:
+    for path in get_subpackage_paths():
+        schema_directory = os.path.join(path, 'schemas/')
+        if os.path.isdir(schema_directory):
+            for spec_file in [i for i in os.listdir(schema_directory) if i.endswith('yaml') or i.endswith("yml")]:
+                with open(os.path.join(schema_directory, spec_file), 'rt') as f:
                     spec = yaml.safe_load(f)
                 app.add_api(specification=spec, validate_responses=debug)
     return app
